%Filename: tempmod.m
%Author: Oeystein Lervik
%Last update: 26.05.2016
%Description: This script makes a fluid temperature model for heat
%transfer during production, using the theory from Ramey, Willhite, 
%Sagar & Doty and Hasan & Kabir. It is used for the Master's Thesis 
%for Oeystein Lervik

clear all
%Reading excel-file with well trajectory input. TVD, MD, inclination 
%and undisturbed geothermal temperature.
input=xlsread('tempmodel2.xlsm','Well Trajectory');

%Flipping the input from the excel-file, and adding each input to the
%appropriate vector. MD=measured depth, TVD=true vertical depth,
%INC=inclination (90-well angle), T_e=undisturbed geothermal 
%temperature 
well_traj=flipud(input);
MD=well_traj(:,9);
TVD=well_traj(:,10);
INC=well_traj(:,12);
theta=INC;
T_e=well_traj(:,13);

%Values used for a vertical well
%{
well_traj=flipud(input);
MD=well_traj(:,4);
TVD=well_traj(:,5);
INC=well_traj(:,6);
theta=INC;
T_e=well_traj(:,7);
%}

%Diameters for each section of the well, with the assosiated wellbore
%diameters. Production liner and tubing:7", production casing:9 5/8",
%intermediate casing:13 3/8", surface casing:20",
%conductor casing:30".
d_7=7;%in
d_9=9+5/8;%in
d_13=13+3/8;%in
d_20=20;%in
d_30=30;%in
d_wb_7=8.5;%in
d_wb_9=12.25;%in
d_wb_13=17.5;%in
d_wb_20=26;%in
d_wb_30=36;%in

%Defining the shoe depth and top of cement depth for each section.
shoe_7=19289.1;%ft
shoe_9=14150.3;%ft
shoe_13=6955.4;%ft
shoe_20=2624.7;%ft
shoe_30=1197.5;%ft
TOC_7=13986.2;%ft
TOC_9=12837.9;%ft
TOC_13=5643;%ft
TOC_20=MD(end);%ft
TOC_30=MD(end);%ft
mudline=MD(end);%ft

%Values used for a vertical well
%{
shoe_7=13294;%ft
shoe_9=11900;%ft
shoe_13=6955.4;%ft
shoe_20=3280.4;%ft
shoe_30=1378;%ft
TOC_7=11811;%ft
TOC_9=8043;%ft
TOC_13=5643;%ft
TOC_20=MD(end);%ft
TOC_30=MD(end);%ft
%}

%Defining the thickness for each pipe
t_7=0.498/12;%ft
t_9=0.545/12;%ft
t_13=0.514/12;%ft
t_20=0.635/12;%ft
t_30=1/12;%ft

%Outer and inner radiuses
r_to=d_7/2/12;%ft
r_ti=r_to-t_7;%ft
r_co_9=d_9/2/12;%ft
r_ci_9=r_co_9-t_9;%ft
r_co_13=d_13/2/12;%ft
r_ci_13=r_co_13-t_13;%ft
r_co_20=d_20/2/12;%ft
r_ci_20=r_co_20-t_20;%ft
r_co_30=d_30/2/12;%ft
r_ci_30=r_co_30-t_30;%ft

%Defining all the necessary input values:

%Conductivities for tubing, casing, cement, formation and A-,B- and
%C-annulus
k_tub=26.2;%Btu/hr*ft^2*F
k_cas=26.2;%Btu/hr*ft^2*F
k_cem=0.568;%Btu/hr*ft^2*F
k_e=0.92;%Btu/hr*ft^2*F
k_an_a=0.35;%Btu/hr*ft^2*F
k_an_b=0.35;%Btu/hr*ft^2*F
k_an_c=0.35;%Btu/hr*ft^2*F

%Emissivities for tubing and casing
e_to=0.85;
e_co=0.85;
e_ci=0.85;

%Formation heat diffusivity=0.022
a=0.022;%ft^2/hr

%Geothermal gradient
g_T=1.43/100;%F/100ft

%Density of the fluids in the A-,B- and C-annulus
rho_an_a=78.03;%lbm/ft^3
rho_an_b=109.25;%lbm/ft^3
rho_an_c=90.52;%lbm/ft^3

%Viscosity of the fluids in the A-,B- and C-annulus
my_an_a=60;%lbm/ft*hr
my_an_b=60;%lbm/ft*hr
my_an_c=60;%lbm/ft*hr

%Heat capacity of the fluids in the A-,B- and C-annulus and the
%flowing fluid
cp_an_a=0.95;%Btu/lbm-F
cp_an_b=0.95;%Btu/lbm-F
cp_an_c=0.95;%Btu/lbm-F
cp_m=0.7;%Btu/lbm-F

%Wellhead pressure
p_wh=14.7;%psi

%Time=2000
t=2000;%hr

%Total mass flow rate=70*3600
w_t=70*3600;%lbm/hr

%Conversion factor
J=778;%ft*lbf/Btu

%Stephan-Boltzmann constant
SB=1.713e-9;%ft^2-hr-R^4

%Conversion factor
g_c=32.2;%ft*lbm/sec^2*lbf

%Gravity acceleration
g_a=32.2;%ft/sec^2

%Gas-oil-ratio, oil gravity and gas specific gravity, for w_t < 5 
%lbm/sec, when the following equation applies:
%phi=-2.978E-3+1.006E-6*p_wh+1.906E-4*w_t-1.047E-6*GOR+3.229E-5*y_API+
%4.009E-3*y_g-0.3551*g_T;
%GOR=1122.916;
%y_API=32;
%y_g=0.749;
phi=0;


%C variable from Dropkin and Sommerscales. Extrapolated in Excel, 
%resulting in the following equation:
%y = 2E-08*(x^3) - 4E-06*(x^2) - 7E-05*(x) + 0.0691
%Values used to extrapolate: 0deg->C=0.069,30deg->C=0.065,
%45deg->C=0.059, 60deg->C=0.057,90deg->C=0.049
C=zeros(size(MD));
for j=1:length(C)
    C(j)=2e-8*((INC(j)*(180/pi()))^3)-4e-6*((INC(j)*(180/pi()))^2)-...
        7e-5*(INC(j)*(180/pi()))+0.0691;
end

%Assigning vectors with the same size as MD with zeros. Vectors for 
%fluid temperature (T_f), overall heat transfer coefficient (U_to),
%outside (T_co) and inside (T_ci) casing temperatures and wellbore
%temperature (T_wb) all given in F. Q=heat loss to formation (Btu/hr). 
T_f=zeros(size(MD));
U_to=zeros(size(MD));
T_co_9=zeros(size(MD));
T_ci_9=zeros(size(MD));
T_co_13=zeros(size(MD));
T_ci_13=zeros(size(MD));
T_co_20=zeros(size(MD));
T_ci_20=zeros(size(MD));
T_co_30=zeros(size(MD));
T_ci_30=zeros(size(MD));
T_wb=zeros(size(MD));
Q=zeros(size(MD));

%Initial values for T_f and U_to
T_f(1)=T_e(1);
U_to(1)=1/(r_to*log(r_to/r_ti)/k_tub+r_to*log((d_wb_7/2/12)/r_to)/...
    k_cem);

%Counter for while-loops, that is changed when convergence is reached
counter=2;

%Variables used in the following for-loop:
%r_wb=wellbore radius for specified section (ft)
%t_D=dimensionless time
%T_D=dimensionless temperature
%A=inverse relaxation distance (ft)
%x=variable for T_f equation
%F_tci_(a/b/c)=view factor (dimensionless) for the respective annulus
%h_c_(a/b/c)=convective heat transfer coefficient for respective 
%annulus (Btu/hr-ft^2-F)
%h_r_(a/b/c)=radiative heat transfer coefficient for respective 
%annulus T_an=average temperature of fluid in annulus (R)
%b=thermal volumetric expansion coefficient of annulus fluid (R^-1)
%Gr=Grashof number (dimensionless)
%Pr=Prandtl number (dimensionless)
%flag is created to break out of the iterations together with "break"

for i=2:length(MD)
    %Values for the bottom section, with the production tubing below 
    %the production casing
    if MD(i)<=shoe_7 && MD(i)>shoe_9
        %U_to is constant for this section, since it is all with one
        %annulus and cemented 
        U_to(i)=U_to(1);
        r_wb=d_wb_7/2/12;
        t_D=a*t/(r_wb^2);
        if t_D>=(1e-10)&&t_D<=1.5
            T_D=1.1281*sqrt(t_D)*(1-0.3*sqrt(t_D));
        else
            T_D=(0.4063+0.5*log(t_D))*(1+0.6/t_D);
        end
        T_wb(1)=(T_f(1)*T_D+(k_e*T_e(1))/(r_to*U_to(1)))/...
            (T_D+k_e/(r_to*U_to(1)));
        T_wb(i)=(T_f(i-1)*T_D+(k_e*T_e(i))/(r_to*U_to(i)))/...
            (T_D+k_e/(r_to*U_to(i)));
        A=((cp_m*w_t)/(2*pi()))*((k_e+r_to*U_to(i)*T_D)/...
            (r_to*U_to(i)*k_e));
        x=(-g_a*sin(theta(i))/(g_c*J*cp_m))+g_T*sin(theta(i))+phi;
        T_f(i)=T_e(i)+A*(1-exp(-(MD(i-1)-MD(i))/A))*x+...
            exp(-(MD(i-1)-MD(i))/A)*(T_f(i-1)-T_e(i-1));
        Q(i)=(MD(i-1)-MD(i))*w_t*cp_m*(1/A)*(T_f(i)-T_e(i));
    %Since the production liner TOC is above the production 
    %casing shoe, the calculation for that part needs to be done here    
    elseif MD(i)<=shoe_9 && MD(i)>=TOC_7
        r_wb=d_wb_9/2/12;
        t_D=a*t/(r_wb^2);
        if t_D>=(1e-10)&&t_D<=1.5
            T_D=1.1281*sqrt(t_D)*(1-0.3*sqrt(t_D));
        else
            T_D=(0.4063+0.5*log(t_D))*(1+0.6/t_D);
        end
        T_wb(i)=(T_f(i-1)*T_D+(k_e*T_e(i))/(r_to*U_to(i-1)))/...
            (T_D+k_e/(r_to*U_to(i-1)));
        U_to(i)=1/(r_to*log(r_to/r_ti)/k_tub+...
            r_to*log(r_ci_9/r_to)/k_cem+...
            r_to*log(r_wb/r_co_9)/k_cem+...
            r_to*log(r_co_9/r_ci_9)/k_cas);
        A=((cp_m*w_t)/(2*pi()))*((k_e+r_to*U_to(i)*T_D)/...
            (r_to*U_to(i)*k_e));
        x=(-g_a*sin(theta(i))/(g_c*J*cp_m))+g_T*sin(theta(i))+phi;
        T_f(i)=T_e(i)+A*(1-exp(-(MD(i-1)-MD(i))/A))*x+...
            exp(-(MD(i-1)-MD(i))/A)*(T_f(i-1)-T_e(i-1));
        Q(i)=(MD(i-1)-MD(i))*w_t*cp_m*(1/A)*(T_f(i)-T_e(i));
    %Values for the production casing below the intermediate casing   
    elseif MD(i)<shoe_9 && MD(i)>=shoe_13
        flag=0;
        r_wb=d_wb_9/2/12;
        t_D=a*t/(r_wb^2);
        if t_D>=(1e-10)&&t_D<=1.5
            T_D=1.1281*sqrt(t_D)*(1-0.3*sqrt(t_D));
        else
            T_D=(0.4063+0.5*log(t_D))*(1+0.6/t_D);
        end
        counter=2;
        while counter>1
            %The section where the production casing is cemented, 
            %above the cemented production liner
            if MD(i)<shoe_9 && MD(i)>=TOC_9
                T_wb(i)=(T_f(i-1)*T_D+(k_e*T_e(i))/...
                    (r_to*U_to(i-1)))/(T_D+k_e/(r_to*U_to(i-1)));
                T_co_9(i)=T_wb(i)+r_to*U_to(i-1)*log(r_wb/r_co_9)*...
                    (T_f(i-1)-T_wb(i))/k_cem;
                %Iterate T_co_9
                if abs(T_co_9(i)-T_co_9(i-1))<1e-10
                    T_ci_9(i)=T_co_9(i)+r_to*U_to(i-1)*...
                        log(r_co_9/r_ci_9)*(T_f(i-1)-T_wb(i))/k_cas;
                    F_tci=1/(1/e_to+r_to*(1/e_ci-1)/r_ci_9);
                    h_r=SB*F_tci*(((T_f(i-1)+460)^2)+...
                        ((T_ci_9(i)+460)^2))*((T_f(i-1)+460)+...
                        (T_ci_9(i)+460));
                    T_an=(T_f(i-1)+T_ci_9(i))/2;
                    b=1/(T_an+460);
                    Gr=((r_ci_9-r_to)^3)*g_a*(3600^2)*...
                        (rho_an_a^2)*b*abs(T_f(i-1)-T_ci_9(i))/...
                        (my_an_a^2);
                    Pr=cp_an_b*my_an_b/k_an_b;
                    h_c=(C(i)*(((Gr*Pr))^(1/3))*(Pr^0.074)*k_an_a)/...
                        (r_to*log(r_ci_9/r_to));
                    U_to(i)=1/(r_to*log(r_to/r_ti)/k_tub+...
                        1/(h_c+h_r)+...
                        r_to*log(r_co_9/r_ci_9)/k_cas+...
                        r_to*log(r_wb/r_co_9)/k_cem);
                    %Iterate U_to 
                    if abs(U_to(i)-U_to(i-1))<1e-10  
                        flag=1;
                        break
                    else
                        %New value if no convergence
                        U_to(i-1)=U_to(i);
                    end
                    if flag==1
                        counter=1;
                        break
                    end
                else
                    %New value if no convergence
                    T_co_9(i-1)=T_co_9(i);
                end
            %The section of the production casing with two annulus,
            %that is below the intermediate casing
            else
                T_wb(i)=(T_f(i-1)*T_D+(k_e*T_e(i))/...
                    (r_to*U_to(i-1)))/(T_D+k_e/(r_to*U_to(i-1)));
                F_tci_b=1/(1/e_co+r_co_9*(1/e_ci-1)/r_wb);
                h_r_b=SB*F_tci_b*(((T_co_9(i-1)+460)^2)+...
                    ((T_wb(i)+460)^2))*((T_co_9(i-1)+460)+...
                    (T_wb(i)+460));
                T_an_b=(T_co_9(i-1)+T_wb(i))/2;
                b_b=1/(T_an_b+460);
                Gr_b=((r_wb-r_co_9)^3)*g_a*(3600^2)*(rho_an_b^2)*...
                    b_b*abs(T_co_9(i-1)-T_wb(i))/(my_an_b^2);
                Pr_b=cp_an_b*my_an_b/k_an_b;
                h_c_b=(C(i)*(((Gr_b*Pr_b))^(1/3))*...
                    (Pr_b^0.074)*k_an_b)/(r_to*log(r_wb/r_co_9));
                T_co_9(i)=T_wb(i)+r_to*U_to(i-1)*...
                    (1/(r_co_9*(h_r_b+h_c_b)))*(T_f(i-1)-T_wb(i));
                %Iterate T_co_9
                if abs(T_co_9(i)-T_co_9(i-1))<1e-10
                    T_ci_9(i)=T_co_9(i)+r_to*U_to(i-1)*...
                        log(r_co_9/r_ci_9)*(T_f(i-1)-T_wb(i))/k_cas;
                    F_tci=1/(1/e_to+r_to*(1/e_ci-1)/r_ci_9);
                    h_r=SB*F_tci*(((T_f(i-1)+460)^2)+...
                        ((T_ci_9(i)+460)^2))*((T_f(i-1)+460)+...
                        (T_ci_9(i)+460));
                    T_an=(T_f(i-1)+T_ci_9(i))/2;
                    b=1/(T_an+460);
                    Gr=((r_ci_9-r_to)^3)*g_a*(3600^2)*...
                        (rho_an_a^2)*b*abs(T_f(i-1)-T_ci_9(i))/...
                        (my_an_a^2);
                    Pr=cp_an_a*my_an_a/k_an_a;
                    h_c=(C(i)*(((Gr*Pr))^(1/3))*(Pr^0.074)*k_an_a)/...
                        (r_to*log(r_ci_9/r_to));
                    U_to(i)=1/(r_to*log(r_to/r_ti)/k_tub+...
                        1/(h_c+h_r)+...
                        r_to/(r_co_9*(h_c_b+h_r_b))+...
                        r_to*log(r_co_9/r_ci_9)/k_cas);
                    %Iterate U_to 
                    if abs(U_to(i)-U_to(i-1))<1e-10 
                        flag=1;
                        break
                    else
                        %New value if no convergence
                        U_to(i-1)=U_to(i);
                    end
                    if flag==1
                        counter=1;
                        break
                    end
                else
                    %New value if no convergence
                    T_co_9(i-1)=T_co_9(i);
                end
            end
        end
        A=((cp_m*w_t)/(2*pi()))*((k_e+r_to*U_to(i)*T_D)/...
            (r_to*U_to(i)*k_e));
        x=(-g_a*sin(theta(i))/(g_c*J*cp_m))+g_T*sin(theta(i))+phi;
        T_f(i)=T_e(i)+A*(1-exp(-(MD(i-1)-MD(i))/A))*x+...
            exp(-(MD(i-1)-MD(i))/A)*(T_f(i-1)-T_e(i-1));
        Q(i)=(MD(i-1)-MD(i))*w_t*cp_m*(1/A)*(T_f(i)-T_e(i));
    %Values for the intermediate casing below the surface casing   
    elseif MD(i)<shoe_13 && MD(i)>=shoe_20 
        r_wb=d_wb_13/2/12;
        t_D=a*t/(r_wb^2);
        if t_D>=(1e-10)&&t_D<=1.5
            T_D=1.1281*sqrt(t_D)*(1-0.3*sqrt(t_D));
        else
            T_D=(0.4063+0.5*log(t_D))*(1+0.6/t_D);
        end
        flag=0;
        counter=2;
        while counter>1
            %Cemented section of the intermediate casing
            if MD(i)<shoe_13 && MD(i)>=TOC_13
                T_wb(i)=(T_f(i-1)*T_D+(k_e*T_e(i))/...
                    (r_to*U_to(i-1)))/(T_D+k_e/(r_to*U_to(i-1)));
                T_ci_13(i)=T_wb(i)+r_to*U_to(i-1)*...
                    (log(r_wb/r_co_13)/k_cem+...
                    log(r_co_13/r_ci_13)/k_cas)*(T_f(i-1)-T_wb(i));
                F_tci=1/(1/e_co+r_co_9*(1/e_ci-1)/r_ci_13);
                h_r_b=SB*F_tci*(((T_co_9(i-1)+460)^2)+...
                    ((T_ci_13(i)+460)^2))*((T_co_9(i-1)+460)+...
                    (T_ci_13(i)+460));
                T_an_b=(T_co_9(i-1)+T_ci_13(i))/2;
                b_b=1/(T_an_b+460);
                Gr_b=((r_ci_13-r_co_9)^3)*g_a*(3600^2)*...
                    (rho_an_b^2)*b_b*abs(T_co_9(i-1)-T_ci_13(i))/...
                    (my_an_b^2);
                Pr_b=cp_an_b*my_an_b/k_an_b;
                h_c_b=(C(i)*(((Gr_b*Pr_b))^(1/3))*...
                    (Pr_b^.074)*k_an_b)/(r_co_9*log(r_ci_13/r_co_9));
                T_co_9(i)=T_ci_13(i)+((r_to*U_to(i-1))/...
                    (r_co_9*(h_r_b+h_c_b)))*(T_f(i-1)-T_wb(i));
                %Iterate T_co_9
                if abs(T_co_9(i)-T_co_9(i-1))<1e-10
                    T_ci_9(i)=T_co_9(i)+r_to*U_to(i-1)*...
                        log(r_co_9/r_ci_9)*(T_f(i-1)-T_wb(i))/k_cas;
                    F_tci=1/(1/e_to+r_to*(1/e_ci-1)/r_ci_9);
                    h_r_a=SB*F_tci*(((T_f(i-1)+460)^2)+...
                        ((T_ci_9(i)+460)^2))*((T_f(i-1)+460)+...
                        (T_ci_9(i)+460));
                    T_an_a=(T_f(i-1)+T_ci_9(i))/2;
                    b_a=1/(T_an_a+460);
                    Gr_a=((r_ci_9-r_to)^3)*g_a*(3600^2)*...
                        (rho_an_a^2)*b_a*abs(T_f(i-1)-T_ci_9(i))/...
                        (my_an_a^2);
                    Pr_a=cp_an_a*my_an_a/k_an_a;
                    h_c_a=(C(i)*(((Gr_a*Pr_a))^(1/3))*...
                        (Pr_a^.074)*k_an_a)/(r_to*log(r_ci_9/r_to));
                    U_to(i)=1/(1/(h_r_a+h_c_a)+...
                        r_to/(r_co_9*(h_r_b+h_c_b))+...
                        r_to*log(r_wb/r_co_13)/k_cem+...
                        r_to*log(r_co_13/r_ci_13)/k_cas+...
                        r_to*log(r_co_9/r_ci_9)/k_cas+...
                        r_to*log(r_to/r_ti)/k_tub);
                    %Iterate U_to
                    if abs(U_to(i)-U_to(i-1))<1e-10
                        flag=1;
                        break
                    else
                        %New value if no convergence
                        U_to(i-1)=U_to(i);
                    end
                    if flag==1
                        counter=1;
                        break
                    end
                else
                    %New value if no convergence
                    T_co_9(i-1)=T_co_9(i);
                end
            %Section of the intermediate casing with three annulus,
            %below the surface casing
            else
                T_wb(i)=(T_f(i-1)*T_D+(k_e*T_e(i))/...
                    (r_to*U_to(i-1)))/(T_D+k_e/(r_to*U_to(i-1)));
                F_tci=1/(1/e_co+r_co_13*(1/e_ci-1)/r_wb);
                h_r_c=SB*F_tci*(((T_co_13(i-1)+460)^2)+...
                    ((T_wb(i)+460)^2))*((T_co_13(i-1)+460)+...
                    (T_wb(i)+460));
                T_an_c=(T_co_13(i-1)+T_wb(i))/2;
                b_c=1/(T_an_c+460);
                Gr_c=((r_wb-r_co_13)^3)*g_a*(3600^2)*...
                    (rho_an_c^2)*b_c*abs(T_co_13(i-1)-T_wb(i))/...
                    (my_an_c^2);
                Pr_c=cp_an_c*my_an_c/k_an_c;
                h_c_c=(C(i)*(((Gr_c*Pr_c))^(1/3))*...
                    (Pr_c^.074)*k_an_c)/(r_co_13*log(r_wb/r_co_13));
                T_co_13(i)=T_wb(i)+r_to*U_to(i-1)/...
                    (r_co_13*(h_r_c+h_c_c))*(T_f(i-1)-T_wb(i));
                %Iterate T_co_13
                if abs(T_co_13(i)-T_co_13(i-1))<1e-10   
                    T_ci_13(i)=T_co_13(i)+r_to*U_to(i-1)*...
                        (log(r_co_13/r_ci_13)/k_cas)*...
                        (T_f(i-1)-T_wb(i));
                    F_tci=1/(1/e_co+r_co_9*(1/e_ci-1)/r_ci_13);
                    h_r_b=SB*F_tci*(((T_co_9(i-1)+460)^2)+...
                        ((T_ci_13(i)+460)^2))*((T_co_9(i-1)+460)+...
                        (T_ci_13(i)+460));
                    T_an_b=(T_co_9(i-1)+T_ci_13(i))/2;
                    b_b=1/(T_an_b+460);
                    Gr_b=((r_ci_13-r_co_9)^3)*g_a*(3600^2)*...
                        (rho_an_b^2)*b_b*...
                        abs(T_co_9(i-1)-T_ci_13(i))/(my_an_b^2);
                    Pr_b=cp_an_b*my_an_b/k_an_b;
                    h_c_b=(C(i)*(((Gr_b*Pr_b))^(1/3))*...
                        (Pr_b^.074)*k_an_b)/...
                        (r_co_9*log(r_ci_13/r_co_9));
                    T_co_9(i)=T_ci_13(i)+((r_to*U_to(i-1))/...
                        (r_co_9*(h_r_b+h_c_b)))*(T_f(i-1)-T_wb(i));
                    %Iterate T_co_9
                    if abs(T_co_9(i)-T_co_9(i-1))<1e-10
                        T_ci_9(i)=T_co_9(i)+r_to*U_to(i-1)*...
                            log(r_co_9/r_ci_9)*...
                            (T_f(i-1)-T_wb(i))/k_cas;
                        F_tci=1/(1/e_to+r_to*(1/e_ci-1)/r_ci_9);
                        h_r_a=SB*F_tci*(((T_f(i-1)+460)^2)+...
                            ((T_ci_9(i)+460)^2))*((T_f(i-1)+460)+...
                            (T_ci_9(i)+460));
                        T_an_a=(T_f(i-1)+T_ci_9(i))/2;
                        b_a=1/(T_an_a+460);
                        Gr_a=((r_ci_9-r_to)^3)*g_a*(3600^2)*...
                            (rho_an_a^2)*b_a*...
                            abs(T_f(i-1)-T_ci_9(i))/(my_an_a^2);
                        Pr_a=cp_an_a*my_an_a/k_an_a;
                        h_c_a=(C(i)*(((Gr_a*Pr_a))^(1/3))*...
                            (Pr_a^.074)*k_an_a)/...
                            (r_to*log(r_ci_9/r_to));
                        U_to(i)=1/(1/(h_r_a+h_c_a)+...
                            r_to/(r_co_9*(h_r_b+h_c_b))+...
                            r_to/(r_co_13*(h_r_c+h_c_c))+...
                            r_to*log(r_co_13/r_ci_13)/k_cas+...
                            r_to*log(r_co_9/r_ci_9)/k_cas+...
                            r_to*log(r_to/r_ti)/k_tub);
                        %Iterate U_to
                        if abs(U_to(i)-U_to(i-1))<1e-10
                            flag=1;
                            break
                        else
                            %New value if no convergence
                            U_to(i-1)=U_to(i);
                        end
                        if flag==1
                            counter=1;
                            break
                        end
                    else
                        %New value if no convergence
                        T_co_9(i-1)=T_co_9(i);
                    end
                else
                    %New value if no convergence
                    T_co_13(i-1)=T_co_13(i);
                end
            end
        end
        A=((cp_m*w_t)/(2*pi()))*((k_e+r_to*U_to(i)*T_D)/...
            (r_to*U_to(i)*k_e));
        x=(-g_a*sin(theta(i))/(g_c*J*cp_m))+g_T*sin(theta(i))+phi;
        T_f(i)=T_e(i)+A*(1-exp(-(MD(i-1)-MD(i))/A))*x+...
            exp(-(MD(i-1)-MD(i))/A)*(T_f(i-1)-T_e(i-1));
        Q(i)=(MD(i-1)-MD(i))*w_t*cp_m*(1/A)*(T_f(i)-T_e(i));
    %Values for the surface casing, below the conductor. 
    %Cemented to the top, so one section.    
    elseif MD(i)<shoe_20 && MD(i)>=shoe_30
        r_wb=d_wb_20/2/12;
        t_D=a*t/(r_wb^2);
        if t_D>=(1e-10)&&t_D<=1.5
            T_D=1.1281*sqrt(t_D)*(1-0.3*sqrt(t_D));
        else
            T_D=(0.4063+0.5*log(t_D))*(1+0.6/t_D);
        end
        flag=0;
        counter=2;
        while counter>1
            T_wb(i)=(T_f(i-1)*T_D+(k_e*T_e(i))/(r_to*U_to(i-1)))/...
                (T_D+k_e/(r_to*U_to(i-1)));
            T_ci_20(i)=T_wb(i)+r_to*U_to(i-1)*...
                (log(r_wb/r_co_20)/k_cem+...
                log(r_co_20/r_ci_20)/k_cas)*(T_f(i-1)-T_wb(i));
            F_tci=1/(1/e_co+r_co_13*(1/e_ci-1)/r_ci_20);
            h_r_c=SB*F_tci*(((T_co_13(i-1)+460)^2)+...
                ((T_ci_20(i)+460)^2))*((T_co_13(i-1)+460)+...
                (T_ci_20(i)+460));
            T_an_c=(T_co_13(i-1)+T_ci_20(i))/2;
            b_c=1/(T_an_c+460);
            Gr_c=((r_ci_20-r_co_13)^3)*g_a*(3600^2)*(rho_an_c^2)*...
                b_c*abs(T_co_13(i-1)-T_ci_20(i))/(my_an_c^2);
            Pr_c=cp_an_c*my_an_c/k_an_c;
            h_c_c=(C(i)*(((Gr_c*Pr_c))^(1/3))*(Pr_c^.074)*k_an_c)/...
                (r_co_13*log(r_ci_20/r_co_13));
            T_co_13(i)=T_ci_20(i)+((r_to*U_to(i-1))/...
                (r_co_13*(h_r_c+h_c_c)))*(T_f(i-1)-T_wb(i));
            %Iterate T_co_13
            if abs(T_co_13(i)-T_co_13(i-1))<1e-10
                T_ci_13(i)=T_co_13(i)+r_to*U_to(i-1)*...
                    (log(r_co_13/r_ci_13)/k_cas)*(T_f(i-1)-T_wb(i));
                F_tci=1/(1/e_co+r_co_9*(1/e_ci-1)/r_ci_13);
                h_r_b=SB*F_tci*(((T_co_9(i-1)+460)^2)+...
                    ((T_ci_13(i)+460)^2))*((T_co_9(i-1)+460)+...
                    (T_ci_13(i)+460));
                T_an_b=(T_co_9(i-1)+T_ci_13(i))/2;
                b_b=1/(T_an_b+460);
                Gr_b=((r_ci_13-r_co_9)^3)*g_a*(3600^2)*...
                    (rho_an_b^2)*b_b*abs(T_co_9(i-1)-T_ci_13(i))/...
                    (my_an_b^2);
                Pr_b=cp_an_b*my_an_b/k_an_b;
                h_c_b=(C(i)*(((Gr_b*Pr_b))^(1/3))*...
                    (Pr_b^.074)*k_an_b)/(r_co_9*log(r_ci_13/r_co_9));
                T_co_9(i)=T_ci_13(i)+((r_to*U_to(i-1))/...
                    (r_co_9*(h_r_b+h_c_b)))*(T_f(i-1)-T_wb(i));
                %Iterate T_co_9
                if abs(T_co_9(i)-T_co_9(i-1))<1e-10
                    T_ci_9(i)=T_co_9(i)+r_to*U_to(i-1)*...
                        log(r_co_9/r_ci_9)*(T_f(i-1)-T_wb(i))/k_cas;
                    F_tci=1/(1/e_to+r_to*(1/e_ci-1)/r_ci_9);
                    h_r_a=SB*F_tci*(((T_f(i-1)+460)^2)+...
                        ((T_ci_9(i)+460)^2))*((T_f(i-1)+460)+...
                        (T_ci_9(i)+460));
                    T_an_a=(T_f(i-1)+T_ci_9(i))/2;
                    b_a=1/(T_an_a+460);
                    Gr_a=((r_ci_9-r_to)^3)*g_a*(3600^2)*...
                        (rho_an_a^2)*b_a*abs(T_f(i-1)-T_ci_9(i))/...
                        (my_an_a^2);
                    Pr_a=cp_an_a*my_an_a/k_an_a;
                    h_c_a=(C(i)*(((Gr_a*Pr_a))^(1/3))*...
                        (Pr_a^.074)*k_an_a)/(r_to*log(r_ci_9/r_to));
                    U_to(i)=1/(1/(h_r_a+h_c_a)+...
                        r_to/(r_co_9*(h_r_b+h_c_b))+...
                        r_to/(r_co_13*(h_r_c+h_c_c))+...
                        r_to*log(r_wb/r_co_20)/k_cem+...
                        r_to*log(r_co_20/r_ci_20)/k_cas+...
                        r_to*log(r_co_13/r_ci_13)/k_cas+...
                        r_to*log(r_co_9/r_ci_9)/k_cas+...
                        r_to*log(r_to/r_ti)/k_tub);
                    %Iterate U_to
                    if abs(U_to(i)-U_to(i-1))<1e-10
                        flag=1;
                        break
                    else
                        %New value if no convergence
                        U_to(i-1)=U_to(i);
                    end
                    if flag==1
                        counter=1;
                        break
                    end
                else
                    %New value if no convergence
                    T_co_9(i-1)=T_co_9(i);
                end
            else
                %New value if no convergence
                T_co_13(i-1)=T_co_13(i);
            end
        end
        A=((cp_m*w_t)/(2*pi()))*((k_e+r_to*U_to(i)*T_D)/...
            (r_to*U_to(i)*k_e));
        x=(-g_a*sin(theta(i))/(g_c*J*cp_m))+g_T*sin(theta(i))+phi;
        T_f(i)=T_e(i)+A*(1-exp(-(MD(i-1)-MD(i))/A))*x+...
            exp(-(MD(i-1)-MD(i))/A)*(T_f(i-1)-T_e(i-1));
        Q(i)=(MD(i-1)-MD(i))*w_t*cp_m*(1/A)*(T_f(i)-T_e(i));
    %Values for the conductor to the mudline. Cemented to the top,
    %so one section
    elseif MD(i)<shoe_30 && MD(i)>=mudline
        r_wb=d_wb_30/2/12;
        t_D=a*t/(r_wb^2);
        if t_D>=(1e-10)&&t_D<=1.5
            T_D=1.1281*sqrt(t_D)*(1-0.3*sqrt(t_D));
        else
            T_D=(0.4063+0.5*log(t_D))*(1+0.6/t_D);
        end
        flag=0;
        counter=2;
        while counter>1
            T_wb(i)=(T_f(i-1)*T_D+(k_e*T_e(i))/(r_to*U_to(i-1)))/...
                (T_D+k_e/(r_to*U_to(i-1)));
            T_ci_20(i)=T_wb(i)+r_to*U_to(i-1)*...
                (log(r_wb/r_co_30)/k_cem+...
                log(r_ci_30/r_co_20)/k_cem+...
                log(r_co_30/r_ci_30)/k_cas+...
                log(r_co_20/r_ci_20)/k_cas)*(T_f(i-1)-T_wb(i));
            F_tci=1/(1/e_co+r_co_20*(1/e_ci-1)/r_ci_30);
            h_r_c=SB*F_tci*(((T_co_13(i-1)+460)^2)+...
                ((T_ci_20(i)+460)^2))*((T_co_13(i-1)+460)+...
                (T_ci_20(i)+460));
            T_an_c=(T_co_13(i-1)+T_ci_20(i))/2;
            b_c=1/(T_an_c+460);
            Gr_c=((r_ci_20-r_co_13)^3)*g_a*(3600^2)*...
                (rho_an_c^2)*b_c*abs(T_co_13(i-1)-T_ci_20(i))/...
                (my_an_c^2);
            Pr_c=cp_an_c*my_an_c/k_an_c;
            h_c_c=(C(i)*(((Gr_c*Pr_c))^(1/3))*(Pr_c^.074)*k_an_c)/...
                (r_co_13*log(r_ci_20/r_co_13));
            T_co_13(i)=T_ci_20(i)+((r_to*U_to(i-1))/...
                (r_co_13*(h_r_c+h_c_c)))*(T_f(i-1)-T_wb(i));
            %Iterate T_co_13
            if abs(T_co_13(i)-T_co_13(i-1))<1e-10
                T_ci_13(i)=T_co_13(i)+r_to*U_to(i-1)*...
                    (log(r_co_13/r_ci_13)/k_cas)*(T_f(i-1)-T_wb(i));
                F_tci=1/(1/e_co+r_co_9*(1/e_ci-1)/r_ci_13);
                h_r_b=SB*F_tci*(((T_co_9(i-1)+460)^2)+...
                    ((T_ci_13(i)+460)^2))*((T_co_9(i-1)+460)+...
                    (T_ci_13(i)+460));
                T_an_b=(T_co_9(i-1)+T_ci_13(i))/2;
                b_b=1/(T_an_b+460);
                Gr_b=((r_ci_13-r_co_9)^3)*g_a*(3600^2)*...
                    (rho_an_b^2)*b_b*abs(T_co_9(i-1)-T_ci_13(i))/...
                    (my_an_b^2);
                Pr_b=cp_an_b*my_an_b/k_an_b;
                h_c_b=(C(i)*(((Gr_b*Pr_b))^(1/3))*...
                    (Pr_b^.074)*k_an_b)/(r_co_9*log(r_ci_13/r_co_9));
                T_co_9(i)=T_ci_13(i)+((r_to*U_to(i-1))/...
                    (r_co_9*(h_r_b+h_c_b)))*(T_f(i-1)-T_wb(i));
                %Iterate T_co_9
                if abs(T_co_9(i)-T_co_9(i-1))<1e-10
                    T_ci_9(i)=T_co_9(i)+r_to*U_to(i-1)*...
                        log(r_co_9/r_ci_9)*(T_f(i-1)-T_wb(i))/k_cas;
                    F_tci=1/(1/e_to+r_to*(1/e_ci-1)/r_ci_9);
                    h_r_a=SB*F_tci*(((T_f(i-1)+460)^2)+...
                        ((T_ci_9(i)+460)^2))*((T_f(i-1)+460)+...
                        (T_ci_9(i)+460));
                    T_an_a=(T_f(i-1)+T_ci_9(i))/2;
                    b_a=1/(T_an_a+460);
                    Gr_a=((r_ci_9-r_to)^3)*g_a*(3600^2)*...
                        (rho_an_a^2)*b_a*abs(T_f(i-1)-T_ci_9(i))/...
                        (my_an_a^2);
                    Pr_a=cp_an_a*my_an_a/k_an_a;
                    h_c_a=(C(i)*(((Gr_a*Pr_a))^(1/3))*...
                        (Pr_a^.074)*k_an_a)/(r_to*log(r_ci_9/r_to));
                    U_to(i)=1/(1/(h_r_a+h_c_a)+...
                        r_to/(r_co_9*(h_r_b+h_c_b))+...
                        r_to/(r_co_13*(h_r_c+h_c_c))+...
                        r_to*log(r_wb/r_co_30)/k_cem+...
                        r_to*log(r_ci_30/r_co_20)/k_cem+...
                        r_to*log(r_co_30/r_ci_30)/k_cas+...
                        r_to*log(r_co_20/r_ci_20)/k_cas+...
                        r_to*log(r_co_13/r_ci_13)/k_cas+...
                        r_to*log(r_co_9/r_ci_9)/k_cas+...
                        r_to*log(r_to/r_ti)/k_tub);
                    %Iterate U_to
                    if abs(U_to(i)-U_to(i-1))<1e-10
                        flag=1;
                        break
                    else
                        %New value if no convergence
                        U_to(i-1)=U_to(i);
                    end
                    if flag==1
                        counter=1;
                        break
                    end
                else
                    %New value if no convergence
                    T_co_9(i-1)=T_co_9(i);
                end
            else
                %New value if no convergence
                T_co_13(i-1)=T_co_13(i);
            end
        end
        A=((cp_m*w_t)/(2*pi()))*((k_e+r_to*U_to(i)*T_D)/...
            (r_to*U_to(i)*k_e));
        x=(-g_a*sin(theta(i))/(g_c*J*cp_m))+g_T*sin(theta(i))+phi;
        T_f(i)=T_e(i)+A*(1-exp(-(MD(i-1)-MD(i))/A))*x+...
            exp(-(MD(i-1)-MD(i))/A)*(T_f(i-1)-T_e(i-1));
        Q(i)=(MD(i-1)-MD(i))*w_t*cp_m*(1/A)*(T_f(i)-T_e(i));
    end     
end

%Plot of fluid temperature, wellbore temperature and geothermal 
%temperature
figure
h1=axes;
plot(flipud(T_f),flipud(MD));
grid on
hold on
plot(flipud(T_wb),flipud(MD));
hold on
plot(flipud(T_e),flipud(MD));
set(h1, 'Ydir', 'reverse')
xlabel('Temperature (?F)');
ylabel('MD (ft)');
title('Temperature model of flowing fluid in a well');
legend('Tf vs MD','Twb vs MD','Tgeo vs MD');

%Plot of overall heat transfer coefficient
figure
h2=axes;
plot(flipud(U_to),flipud(MD));
grid on
set(h2, 'Ydir', 'reverse')
xlabel('Uto (Btu/hr ft^2 ?F)');
ylabel('MD (ft)');
title('Heat transfer coefficient vs MD');
legend('Uto vs MD');

%Plot of wellbore heat loss
figure
h3=axes;
plot(flipud(Q),flipud(MD));
grid on
set(h3, 'Ydir', 'reverse')
xlabel('Q (Btu/hr)');
ylabel('MD (ft)');
title('Wellbore heat loss vs MD');
legend('Q vs MD');
%sum(Q)

%Exporting values to Excel files 
filename='Fluid temperature.xlsx';
filename2='Wellbore temperature.xlsx';
filename3='Geothermal temperature.xlsx';
filename4='MD.xlsx';
filename5='Uto.xlsx';
filename6='TVD.xlsx';
filename7='Heat loss.xlsx';
output=xlswrite('Fluid temperature.xlsx',(flipud(T_f)));
output2=xlswrite('Wellbore temperature.xlsx',round(flipud(T_wb)));
output3=xlswrite('Geothermal temperature.xlsx',round(flipud(T_e)));
output4=xlswrite('MD.xlsx',(flipud(MD)));
output5=xlswrite('Uto.xlsx',(flipud(U_to)));
output6=xlswrite('TVD.xlsx',(flipud(TVD)));
output7=xlswrite('Heat loss',(flipud(Q)));
